@@ -28,21 +28,16 @@ struct _GisCenterContainerPrivate
 {
   GtkWidget *left;
   GtkWidget *center;
-  GtkWidget *right;
 };
+typedef struct _GisCenterContainerPrivate GisCenterContainerPrivate;
 
-G_DEFINE_TYPE (GisCenterContainer, gis_center_container, GTK_TYPE_CONTAINER);
+G_DEFINE_TYPE_WITH_PRIVATE (GisCenterContainer, gis_center_container, GTK_TYPE_CONTAINER);
 
 #define SPACING 6
 
 static void
 gis_center_container_init (GisCenterContainer *center)
 {
-  GisCenterContainerPrivate *priv;
-
-  priv = G_TYPE_INSTANCE_GET_PRIVATE (center, GIS_TYPE_CENTER_CONTAINER, GisCenterContainerPrivate);
-  center->priv = priv;
-
   gtk_widget_set_has_window (GTK_WIDGET (center), FALSE);
 }
 
@@ -52,7 +47,7 @@ gis_center_container_get_preferred_width (GtkWidget *widget,
                                           gint      *natural_size)
 {
   GisCenterContainer *center = GIS_CENTER_CONTAINER (widget);
-  GisCenterContainerPrivate *priv = center->priv;
+  GisCenterContainerPrivate *priv = gis_center_container_get_instance_private (center);
 
   gint sum_min, sum_nat;
   gint child_min, child_nat;
@@ -65,10 +60,6 @@ gis_center_container_get_preferred_width (GtkWidget *widget,
   sum_min = sum_min + child_min;
   sum_nat = sum_nat + child_nat + SPACING;
 
-  gtk_widget_get_preferred_width (priv->right, &child_min, &child_nat);
-  sum_min = sum_min + child_min;
-  sum_nat = sum_nat + child_nat + SPACING;
-
   if (minimum_size)
     *minimum_size = sum_min;
   if (natural_size)
@@ -81,7 +72,7 @@ gis_center_container_get_preferred_height (GtkWidget *widget,
                                            gint      *natural_size)
 {
   GisCenterContainer *center = GIS_CENTER_CONTAINER (widget);
-  GisCenterContainerPrivate *priv = center->priv;
+  GisCenterContainerPrivate *priv = gis_center_container_get_instance_private (center);
   gint max_min, max_nat;
   gint child_min, child_nat;
 
@@ -93,10 +84,6 @@ gis_center_container_get_preferred_height (GtkWidget *widget,
   max_min = MAX (max_min, child_min);
   max_nat = MAX (max_nat, child_nat);
 
-  gtk_widget_get_preferred_height (priv->right, &child_min, &child_nat);
-  max_min = MAX (max_min, child_min);
-  max_nat = MAX (max_nat, child_nat);
-
   if (minimum_size)
     *minimum_size = max_min;
   if (natural_size)
@@ -108,9 +95,9 @@ gis_center_container_size_allocate (GtkWidget     *widget,
                                     GtkAllocation *allocation)
 {
   GisCenterContainer *center = GIS_CENTER_CONTAINER (widget);
-  GisCenterContainerPrivate *priv = center->priv;
+  GisCenterContainerPrivate *priv = gis_center_container_get_instance_private (center);
   GtkAllocation child_allocation;
-  gint max_side;
+  gint left_side;
 
   gtk_widget_set_allocation (widget, allocation);
 
@@ -118,23 +105,14 @@ gis_center_container_size_allocate (GtkWidget     *widget,
   child_allocation.height = allocation->height;
 
   /* XXX -- fix minimum allocations */
-  {
-    gint left_side, right_side;
-    gtk_widget_get_preferred_width (priv->left, NULL, &left_side);
-    gtk_widget_get_preferred_width (priv->right, NULL, &right_side);
-    max_side = MAX (left_side, right_side);
-  }
-
-  child_allocation.width = max_side;
+  gtk_widget_get_preferred_width (priv->left, NULL, &left_side);
 
   child_allocation.x = allocation->x;
+  child_allocation.width = left_side;
   gtk_widget_size_allocate (priv->left, &child_allocation);
 
-  child_allocation.x = allocation->x + allocation->width - max_side;
-  gtk_widget_size_allocate (priv->right, &child_allocation);
-
-  child_allocation.x = allocation->x + max_side + SPACING;
-  child_allocation.width = allocation->width - max_side * 2 - SPACING * 2;
+  child_allocation.x = allocation->x + left_side + SPACING;
+  child_allocation.width = allocation->width - left_side * 2 - SPACING * 2;
   gtk_widget_size_allocate (priv->center, &child_allocation);
 }
 
@@ -151,17 +129,15 @@ gis_center_container_forall (GtkContainer *container,
                              gpointer      callback_data)
 {
   GisCenterContainer *center = GIS_CENTER_CONTAINER (container);
-  GisCenterContainerPrivate *priv = center->priv;
+  GisCenterContainerPrivate *priv = gis_center_container_get_instance_private (center);
 
   callback (priv->left, callback_data);
   callback (priv->center, callback_data);
-  callback (priv->right, callback_data);
 }
 
 static void
 gis_center_container_class_init (GisCenterContainerClass *class)
 {
-  GObjectClass *object_class = G_OBJECT_CLASS (class);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
   GtkContainerClass *container_class = GTK_CONTAINER_CLASS (class);
 
@@ -172,17 +148,14 @@ gis_center_container_class_init (GisCenterContainerClass *class)
   container_class->forall = gis_center_container_forall;
   container_class->child_type = gis_center_container_child_type;
   gtk_container_class_handle_border_width (container_class);
-
-  g_type_class_add_private (object_class, sizeof (GisCenterContainerPrivate));
 }
 
 GtkWidget *
 gis_center_container_new (GtkWidget *left,
-                          GtkWidget *center,
-                          GtkWidget *right)
+                          GtkWidget *center)
 {
   GisCenterContainer *container = g_object_new (GIS_TYPE_CENTER_CONTAINER, NULL);
-  GisCenterContainerPrivate *priv = container->priv;
+  GisCenterContainerPrivate *priv = gis_center_container_get_instance_private (container);
 
   priv->left = left;
   gtk_widget_set_parent (left, GTK_WIDGET (container));
@@ -190,9 +163,6 @@ gis_center_container_new (GtkWidget *left,
   priv->center = center;
   gtk_widget_set_parent (center, GTK_WIDGET (container));
 
-  priv->right = right;
-  gtk_widget_set_parent (right, GTK_WIDGET (container));
-
   return GTK_WIDGET (container);
 }
 
